@@ -252,7 +252,6 @@ Context::Context(QObject *parent)
     d->m_server = new Server(this);
     d->m_context = nullptr;
     d->m_mainloop = nullptr;
-    d->m_references = 0;
 
     d->connectToDaemon();
 
@@ -715,42 +714,42 @@ bool Context::isValid()
     return d->m_context && d->m_mainloop;
 }
 
-QVector<Sink *> Context::sinks() const
+QList<Sink *> Context::sinks() const
 {
     return d->m_sinks.data();
 }
 
-QVector<SinkInput *> Context::sinkInputs() const
+QList<SinkInput *> Context::sinkInputs() const
 {
     return d->m_sinkInputs.data();
 }
 
-QVector<Source *> Context::sources() const
+QList<Source *> Context::sources() const
 {
     return d->m_sources.data();
 }
 
-QVector<SourceOutput *> Context::sourceOutputs() const
+QList<SourceOutput *> Context::sourceOutputs() const
 {
     return d->m_sourceOutputs.data();
 }
 
-QVector<Client *> Context::clients() const
+QList<Client *> Context::clients() const
 {
     return d->m_clients.data();
 }
 
-QVector<Card *> Context::cards() const
+QList<Card *> Context::cards() const
 {
     return d->m_cards.data();
 }
 
-QVector<Module *> Context::modules() const
+QList<Module *> Context::modules() const
 {
     return d->m_modules.data();
 }
 
-QVector<StreamRestore *> Context::streamRestores() const
+QList<StreamRestore *> Context::streamRestores() const
 {
     return d->m_streamRestores.data();
 }
@@ -773,15 +772,18 @@ void ContextPrivate::setGenericVolume(
     newVolume = qBound<qint64>(0, newVolume, PA_VOLUME_MAX);
     pa_cvolume newCVolume = cVolume;
     if (channel == -1) { // -1 all channels
-        const qint64 diff = newVolume - pa_cvolume_max(&cVolume);
+        const qint64 orig = pa_cvolume_max(&cVolume);
+        const qint64 diff = newVolume - orig;
         for (int i = 0; i < newCVolume.channels; ++i) {
-            newCVolume.values[i] = qBound<qint64>(0, newCVolume.values[i] + diff, PA_VOLUME_MAX);
+            const qint64 channel = newCVolume.values[i];
+            const qint64 channelDiff = orig == 0 ? diff : diff * channel / orig;
+            newCVolume.values[i] = qBound<qint64>(0, newCVolume.values[i] + channelDiff, PA_VOLUME_MAX);
         }
     } else {
         Q_ASSERT(newCVolume.channels > channel);
         newCVolume.values[channel] = newVolume;
     }
-    if (!pa_set_volume(m_context, index, &newCVolume, nullptr, nullptr)) {
+    if (!PAOperation(pa_set_volume(m_context, index, &newCVolume, nullptr, nullptr))) {
         qCWarning(PULSEAUDIOQT) << "pa_set_volume failed";
         return;
     }
@@ -829,7 +831,7 @@ void ContextPrivate::setGenericDeviceForStream(
 
 void ContextPrivate::setGenericVolumes(
     quint32 index,
-    QVector<qint64> channelVolumes,
+    QList<qint64> channelVolumes,
     pa_cvolume cVolume,
     const std::function<pa_operation *(pa_context *, uint32_t, const pa_cvolume *, pa_context_success_cb_t, void *)> &pa_set_volume)
 {
