@@ -8,6 +8,7 @@
 
 #include "maps.h"
 #include "operation.h"
+#include <QTimer>
 #include <functional>
 #include <pulse/context.h>
 #include <pulse/ext-stream-restore.h>
@@ -42,7 +43,10 @@ public:
     QString m_newDefaultSink;
     QString m_newDefaultSource;
 
-    int m_references;
+    QTimer m_connectTimer;
+    int m_connectTries;
+
+    static QString s_applicationId;
 
     void subscribeCallback(pa_context *context, pa_subscription_event_type_t type, uint32_t index);
     void contextStateCallback(pa_context *context);
@@ -68,8 +72,14 @@ public:
     void setGenericDeviceForStream(quint32 streamIndex,
                                    quint32 deviceIndex,
                                    const std::function<pa_operation *(pa_context *, uint32_t, uint32_t, pa_context_success_cb_t, void *)> &);
+    void setGenericVolumes(quint32 index,
+                           QList<qint64> channelVolumes,
+                           pa_cvolume cVolume,
+                           const std::function<pa_operation *(pa_context *, uint32_t, const pa_cvolume *, pa_context_success_cb_t, void *)> &);
+
     void reset();
     void connectToDaemon();
+    void checkConnectTries();
 
     Context *q;
 };
