@@ -10,6 +10,7 @@
 #include "context.h"
 #include "context_p.h"
 #include "server.h"
+#include "sinkinput.h"
 
 #include "device_p.h"
 #include "volumeobject_p.h"
@@ -85,9 +86,17 @@ quint32 Sink::monitorIndex() const
     return d->m_monitorIndex;
 }
 
-void Sink::setChannelVolumes(const QVector<qint64> &channelVolumes)
+void Sink::setChannelVolumes(const QList<qint64> &channelVolumes)
 {
     Context::instance()->d->setGenericVolumes(index(), channelVolumes, VolumeObject::d->m_volume, &pa_context_set_sink_volume_by_index);
 }
 
+void Sink::switchStreams()
+{
+    const auto sinkInputs = Context::instance()->sinkInputs();
+    for (const auto &sinkInput : sinkInputs) {
+        sinkInput->setDeviceIndex(index());
+    }
+}
+
 } // PulseAudioQt
