@@ -69,6 +69,19 @@ void Source::setDefault(bool enable)
     }
 }
 
+void Source::switchStreams()
+{
+    const auto sourceOutputs = Context::instance()->sourceOutputs();
+    for (const auto &sourceOutput : sourceOutputs) {
+        sourceOutput->setDeviceIndex(index());
+    }
+}
+
+void Source::setChannelVolumes(const QList<qint64> &volumes)
+{
+    Context::instance()->d->setGenericVolumes(index(), volumes, VolumeObject::d->m_volume, &pa_context_set_source_volume_by_index);
+}
+
 Source::~Source()
 {
     delete d;
